<?php

/*
 * LMS version 1.3.1 Maybourne
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: dbrecover.php,v 1.21 2004/02/21 19:38:17 lukasz Exp $
 */

if($_GET['is_sure'])
{
	$LMS->DatabaseCreate();
	$LMS->DatabaseRecover($_GET['db']);
	header("Location: ?m=".$_SESSION['lastmodule']);
	die;
}else{
	$layout['pagetitle'] = "Odtworzenie bazy danych danych";
	$SMARTY->assign('layout',$layout);
	$SMARTY->display('header.html');
	echo "<H1>Odtworzenie bazy danych danych</H1>";
	echo "<p>Czy jeste pewien e chcesz odtworzy baz danych utworzon dnia ".date("Y/m/d H:i.s",$_GET['db'])."?</p>";
	echo "<a href=\"?m=dbrecover&db=".$_GET['db']."&is_sure=1\">Tak, jestem pewien</A>";
	$SMARTY->display('footer.html');
}

?>